==> blesta-5.10.2.zip: blesta/language/ro_ro/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Editare grup';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Aplicați adresele de e-mail ca nume de utilizator';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Utilizați setările companiei (debifați pentru a specifica mai jos)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Metode de livrare a facturilor';
$lang['AdminCompanyGroups.edit.field_description'] = 'Descriere';
$lang['AdminCompanyGroups.edit.field_color'] = 'Culoare';
$lang['AdminCompanyGroups.edit.field_name'] = 'Nume';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Câmpuri obligatorii pentru client';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Setări generale ale clientului';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Anunțuri';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Livrarea facturilor';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Taxe de întârziere';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Opțiuni de facturare și taxare';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Opțiuni de bază';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Editare grup';
$lang['AdminCompanyGroups.edit.page_title'] = 'Setări > Companie > Grupuri de clienți > Editare grup';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Creați un grup';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Activați Verificarea e-mailului';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Aplicați adresele de e-mail ca nume de utilizator';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Utilizați setările companiei (debifați pentru a specifica mai jos)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Metode de livrare a facturilor';
$lang['AdminCompanyGroups.add.field_description'] = 'Descriere';
$lang['AdminCompanyGroups.add.field_color'] = 'Culoare';
$lang['AdminCompanyGroups.add.field_name'] = 'Nume';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Câmpuri obligatorii pentru client';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Setări generale ale clientului';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Anunțuri';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Livrarea facturilor';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Taxe de întârziere';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Opțiuni de facturare și taxare';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Opțiuni de bază';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Creați un grup';
$lang['AdminCompanyGroups.add.page_title'] = 'Setări > Companie > Grupuri de clienți > Creați un grup';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Sunteți sigur că doriți să ștergeți acest grup de clienți? Toți clienții din acest grup vor fi mutați în grupul implicit.';
$lang['AdminCompanyGroups.index.no_results'] = 'Nu există grupuri de clienți.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Ștergeți';
$lang['AdminCompanyGroups.index.option_edit'] = 'Editați';
$lang['AdminCompanyGroups.index.text_options'] = 'Opțiuni';
$lang['AdminCompanyGroups.index.text_clients'] = 'Număr de clienți';
$lang['AdminCompanyGroups.index.text_description'] = 'Descriere';
$lang['AdminCompanyGroups.index.text_name'] = 'Nume';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Creați un grup';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Grupuri de clienți';
$lang['AdminCompanyGroups.index.page_title'] = 'Setări > Companie > Grupuri de clienți';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Bifați pentru a trimite un e-mail de verificare a e-mailului atunci când este creată o nouă autentificare sau când un client își schimbă adresa de e-mail. O notificare va apărea pe profilul clientului până când acesta va fi verificat.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Elimină posibilitatea ca clienții să își definească propriul nume de utilizator.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s este grupul implicit și nu poate fi șters.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s a fost șters cu succes!';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s a fost editat cu succes!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s a fost creat cu succes!';

==> blesta-5.11.4.zip: blesta/language/ro_ro/admin_company_groups.php <==
<?php
/**
 * Admin Company Groups
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGroups.edit.text_editsubmit'] = 'Editare grup';
$lang['AdminCompanyGroups.edit.field_force_email_usernames'] = 'Aplicați adresele de e-mail ca nume de utilizator';
$lang['AdminCompanyGroups.edit.field_company_settings'] = 'Utilizați setările companiei (debifați pentru a specifica mai jos)';
$lang['AdminCompanyGroups.edit.field_delivery_methods'] = 'Metode de livrare a facturilor';
$lang['AdminCompanyGroups.edit.field_description'] = 'Descriere';
$lang['AdminCompanyGroups.edit.field_color'] = 'Culoare';
$lang['AdminCompanyGroups.edit.field_name'] = 'Nume';
$lang['AdminCompanyGroups.edit.heading_client_fields'] = 'Câmpuri obligatorii pentru client';
$lang['AdminCompanyGroups.edit.heading_client_settings'] = 'Setări generale ale clientului';
$lang['AdminCompanyGroups.edit.heading_payment'] = 'Anunțuri';
$lang['AdminCompanyGroups.edit.heading_delivery'] = 'Livrarea facturilor';
$lang['AdminCompanyGroups.edit.heading_late_fees'] = 'Taxe de întârziere';
$lang['AdminCompanyGroups.edit.heading_invoice'] = 'Opțiuni de facturare și taxare';
$lang['AdminCompanyGroups.edit.heading_basic'] = 'Opțiuni de bază';
$lang['AdminCompanyGroups.edit.boxtitle_editgroup'] = 'Editare grup';
$lang['AdminCompanyGroups.edit.page_title'] = 'Setări > Companie > Grupuri de clienți > Editare grup';
$lang['AdminCompanyGroups.add.text_addsubmit'] = 'Creați un grup';
$lang['AdminCompanyGroups.add.field_email_verification'] = 'Activați Verificarea e-mailului';
$lang['AdminCompanyGroups.add.field_force_email_usernames'] = 'Aplicați adresele de e-mail ca nume de utilizator';
$lang['AdminCompanyGroups.add.field_company_settings'] = 'Utilizați setările companiei (debifați pentru a specifica mai jos)';
$lang['AdminCompanyGroups.add.field_delivery_methods'] = 'Metode de livrare a facturilor';
$lang['AdminCompanyGroups.add.field_description'] = 'Descriere';
$lang['AdminCompanyGroups.add.field_color'] = 'Culoare';
$lang['AdminCompanyGroups.add.field_name'] = 'Nume';
$lang['AdminCompanyGroups.add.heading_client_fields'] = 'Câmpuri obligatorii pentru client';
$lang['AdminCompanyGroups.add.heading_client_settings'] = 'Setări generale ale clientului';
$lang['AdminCompanyGroups.add.heading_payment'] = 'Anunțuri';
$lang['AdminCompanyGroups.add.heading_delivery'] = 'Livrarea facturilor';
$lang['AdminCompanyGroups.add.heading_late_fees'] = 'Taxe de întârziere';
$lang['AdminCompanyGroups.add.heading_invoice'] = 'Opțiuni de facturare și taxare';
$lang['AdminCompanyGroups.add.heading_basic'] = 'Opțiuni de bază';
$lang['AdminCompanyGroups.add.boxtitle_addgroup'] = 'Creați un grup';
$lang['AdminCompanyGroups.add.page_title'] = 'Setări > Companie > Grupuri de clienți > Creați un grup';
$lang['AdminCompanyGroups.index.confirm_delete'] = 'Sunteți sigur că doriți să ștergeți acest grup de clienți? Toți clienții din acest grup vor fi mutați în grupul implicit.';
$lang['AdminCompanyGroups.index.no_results'] = 'Nu există grupuri de clienți.';
$lang['AdminCompanyGroups.index.option_delete'] = 'Ștergeți';
$lang['AdminCompanyGroups.index.option_edit'] = 'Editați';
$lang['AdminCompanyGroups.index.text_options'] = 'Opțiuni';
$lang['AdminCompanyGroups.index.text_clients'] = 'Număr de clienți';
$lang['AdminCompanyGroups.index.text_description'] = 'Descriere';
$lang['AdminCompanyGroups.index.text_name'] = 'Nume';
$lang['AdminCompanyGroups.index.categorylink_addgroup'] = 'Creați un grup';
$lang['AdminCompanyGroups.index.boxtitle_groups'] = 'Grupuri de clienți';
$lang['AdminCompanyGroups.index.page_title'] = 'Setări > Companie > Grupuri de clienți';
$lang['AdminCompanyGroups.!tooltip.email_verification'] = 'Bifați pentru a trimite un e-mail de verificare a e-mailului atunci când este creată o nouă autentificare sau când un client își schimbă adresa de e-mail. O notificare va apărea pe profilul clientului până când acesta va fi verificat.';
$lang['AdminCompanyGroups.!tooltip.force_email_usernames'] = 'Elimină posibilitatea ca clienții să își definească propriul nume de utilizator.';
$lang['AdminCompanyGroups.!error.delete_failed'] = '%1$s este grupul implicit și nu poate fi șters.';
$lang['AdminCompanyGroups.!success.delete_deleted'] = '%1$s a fost șters cu succes!';
$lang['AdminCompanyGroups.!success.edit_updated'] = '%1$s a fost editat cu succes!';
$lang['AdminCompanyGroups.!success.add_created'] = '%1$s a fost creat cu succes!';
$lang['AdminCompanyGroups.edit.heading_gateway_restrictions'] = 'Porți permise';
$lang['AdminCompanyGroups.add.heading_gateway_restrictions'] = 'Porți permise';
